@@ -18,8 +18,6 @@ import datetime
 # Get configuration information from setup.cfg
 from configparser import ConfigParser
 
-import showermodel
-
 conf = ConfigParser()
 conf.read([os.path.join(os.path.dirname(__file__), "..", "setup.cfg")])
 setup_cfg = dict(conf.items("metadata"))
@@ -32,6 +30,7 @@ copyright = "{}.  Last updated {}".format(
     setup_cfg["author"], datetime.datetime.now().strftime("%d %b %Y %H:%M")
 )
 
+import showermodel
 version = showermodel.__version__
 # The full version, including alpha/beta/rc tags.
 release = version
@@ -46,10 +45,12 @@ extensions = [
     'sphinx.ext.coverage',
     'sphinx.ext.githubpages',
     'sphinx.ext.napoleon',
-    'nbsphinx'
+    'nbsphinx',
+    'nbsphinx_link'
 ]
 # Show both the class’ and the __init__ method’s docstring
 autoclass_content = 'both'
+autodoc_member_order = 'bysource'
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -69,7 +70,7 @@ html_theme = 'sphinx_rtd_theme'
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+# html_static_path = ['_static']
 
 # Refer figures
 numfig = True
