@@ -7,130 +7,59 @@ import matplotlib as mpl
 import matplotlib.pyplot as plt
 
 
-# Constructor #################################################################
-def Event(observatory, shower, atm_trans=True, tel_eff=True, **kwargs):
+# Class #######################################################################
+class Event():
     """
-    Construct an Event object from a shower and an observatory.
-    
-    The Event objet contains the signal produced by the shower in each
-    telescope of the observatory.
+    Contain the characteristics of a shower detected by an observatory.
+
+    The signal produced by the shower in each telescope of the observatory is
+    stored in a list. The shower, the observatory, etc. are stored as object
+    attributes.
 
     Parameters
     ----------
-    observatory : Observatory object (may be a Grid object).
-    shower : Shower object.
+    observatory : Observatory
+        Observatory that observes the shower.
+    shower : Shower
+        Shower to be observed.
     atm_trans : bool, default True
         Include the atmospheric transmision to transport photons.
     tel_eff : bool, default True
         Include the telescope efficiency to calculate the signals.
         If False, 100% efficiency is assumed for a given wavelength interval.
-    **kwargs {wvl_ini, wvl_fin, wvl_step}
+    **kwargs : {wvl_ini, wvl_fin, wvl_step}
         These parameters will be passed to the Signal constructor to modify
         the wavelength interval when tel_eff==False. If None, the wavelength
         interval defined in each telescope is used.
 
-    Returns
-    -------
-    event : Event object.
-    """
-    from .observatory import _Observatory, _Grid
-    from .telescope import _Telescope
-    from .shower import _Shower
-    if not isinstance(shower, _Shower):
-        observatory, shower = (shower, observatory)
-        if not isinstance(shower, _Shower):
-            raise ValueError('The input shower is not valid')
-
-    if isinstance(observatory, (_Telescope, _Observatory)):
-        if isinstance(observatory, _Grid):
-            event = _GridEvent()
-            event.grid = observatory
-        else:
-            event = _Event()
-            if isinstance(observatory, _Telescope):
-                telescope = observatory
-                event.observatory = _Observatory()
-                event.observatory.append(telescope)
-            else:
-                event.observatory = observatory
-    else:
-        raise ValueError('The input observatory is not valid')
-
-    event.shower = shower
-    event.atmosphere = shower.atmosphere
-    event.track = shower.track
-    event.profile = shower.profile
-    event.cherenkov = shower.cherenkov
-    event.fluorescence = shower.fluorescence
-
-    event.atm_trans = atm_trans
-    event.tel_eff = tel_eff
-
-    event.projections = []
-    event.signals = []
-    for telescope in observatory:
-        projection = sm.Projection(telescope, event.track)
-        event.projections.append(projection)
-        signal = sm.Signal(
-            telescope, shower, projection, atm_trans, tel_eff, **kwargs)
-        event.signals.append(signal)
-        
-    event.images = None
-
-    return event
-
-
-# Class #######################################################################
-class _Event():
-    """
-    An Event object contains the characteristics of a shower, an observatory and
-    the signal produced by the shower in each telescope.
-
-    Use Event to construct an Event object.
-
     Attributes
     ----------
-    event_type : {'Event', 'GridEvent'} or new name
-        Name of subclass of Event. Presently, only the parent class Event and
-        the subclass GridEvent are available. More subclasses to be implemented.
-    shower : Shower object.
-    track : Track object.
-    profile : Profile object.
-    fluorescence : Fluorescence object.
-    cherenkov : Cherenkov object.
-    atmosphere : Atmosphere object.
-    observatory : Observatory object.
-    grid : Grid object (only for GridEvent objects)
-        It replaces observatory for GridEvent objects.
-    projections : List of Projection objects.
-    signals : List of Signal objects.
-    images : List of Image objects
+    event_type : str
+        Name given to the event. Default to None.
+    shower : Shower
+    track : Track
+    profile : Profile
+    fluorescence : Fluorescence
+    cherenkov : Cherenkov
+    atmosphere : Atmosphere
+    observatory : Observatory
+    projections : list
+        List of Projection objects, one per telescope.
+    signals : list
+        List of Signal objects, one per telescope.
+    images : list or None
+        List of Image objects, one per telescope.
         Only available if generated via the method make_images.
     atm_trans : bool
         True if the atmospheric transmision is included.
     tel_eff : bool
         True if the telescope efficiency is included.
-
-    Methods
-    -------
-    show_projection : Show the projection of the shower track viewed by a
-        telescope in both zenith and camera projections.
-    show_profile : Show the shower profile, both number of charged particles
-        and energy deposit, as a function of slant depth.
-    show_light_production : Show the production of both Cherenkov and
-        fluorescence photons in the 290 - 430 nm range as a function of
-        slant depth.
-    show_signal : Show the signal evolution as a function of both time and beta
-        angle (relative to the shower axis direction) for a chosen telescope of
-        the observatory.
-    show_geometry2D : Show the shower track together with the telescope
-        positions in a 2D plot.
-    show_geometry3D : Show the shower track together with the telescope
-        positions in a 3D plot.
-    make_images : Generate shower images.
-    show_images : Show shower images (if already exist).
     """
-    event_type = None
+
+    def __init__(self, observatory, shower, event_type=None, atm_trans=True,
+                 tel_eff=True, **kwargs):
+        self.event_type = event_type
+        _event(self, observatory, shower, atm_trans, tel_eff, **kwargs)
 
     def show_projection(self, tel_index=0, shower_size=True, axes=True,
                         max_theta=30., X_mark='X_max'):
@@ -157,7 +86,7 @@ class _Event():
 
         Returns
         -------
-        (ax1, ax2) : PolarAxesSubplot objects.
+        (ax1, ax2) : PolarAxesSubplot
         """
         if X_mark == 'X_max':
             X_mark = self.shower.X_max
@@ -174,7 +103,7 @@ class _Event():
 
         Returns
         -------
-        (ax1, ax2) : AxesSubplot objects.
+        (ax1, ax2) : AxesSubplot
         """
         return self.profile.show()
 
@@ -185,7 +114,7 @@ class _Event():
 
         Returns
         -------
-        (ax1, ax2) : AxesSubplot objects.
+        (ax1, ax2) : AxesSubplot
         """
         return self.shower.show_light_production()
 
@@ -202,7 +131,7 @@ class _Event():
 
         Returns
         -------
-        (ax1, ax2) : AxesSubplot objects.
+        (ax1, ax2) : AxesSubplot
         """
         signal = self.signals[tel_index]
         return signal.show()
@@ -249,7 +178,7 @@ class _Event():
 
         Returns
         -------
-        ax : AxesSubplot object.
+        ax : AxesSubplot
         """
         if X_mark == 'X_max':
             X_mark = self.shower.X_max
@@ -294,7 +223,7 @@ class _Event():
 
         Returns
         -------
-        ax : Axes3DSubplot object.
+        ax : Axes3DSubplot
         """
         if X_mark == 'X_max':
             X_mark = self.shower.X_max
@@ -309,7 +238,7 @@ class _Event():
                           N_y=10, atm_trans=None, tel_eff=None, **kwargs):
         """
         Make a GridEvent object and show the distribution of photons
-        (or photoelectrons) per m$^2$ in an either 1D or 2D plot, depending on
+        (or photoelectrons) per m^2 in an either 1D or 2D plot, depending on
         the grid dimensions.
 
         Parameters
@@ -332,20 +261,20 @@ class _Event():
         tel_eff : bool, default True
             Include the telescope efficiency to calculate the signals. If None,
             this option is set to be the same as the original Event object.
-        **kwargs {wvl_ini, wvl_fin, wvl_step}
+        **kwargs : {wvl_ini, wvl_fin, wvl_step}
             These parameters will be passed to the Signal constructor to modify
             the wavelength interval when tel_eff==False. If None, the wavelength
             interval the grid telescopes is used.
 
         Returns
         -------
-        grid_event : GridEvent object.
-        ax : AxesSubplot object (if 1D grid).
-        (ax1, ax2, cbar) : AxesSubplot objects and Colorbar object
-            (if 2D grid).
+        grid_event : GridEvent
+        ax : AxesSubplot 
+            If 1D grid.
+        (ax1, ax2, cbar) : AxesSubplot and Colorbar
+            If 2D grid.
         """
-        from .observatory import _Grid
-        if not isinstance(grid, _Grid):
+        if not isinstance(grid, sm.Grid):
             if grid is None:
                 observatory = self.observatory
                 telescope = observatory[0]  # tel_index=0 is used as reference
@@ -356,8 +285,8 @@ class _Event():
                 theta = telescope.theta
                 alt = telescope.alt
                 az = telescope.az
-                grid =sm.Grid(telescope, tel_type, x_c, y_c, z_c, theta, alt,
-                               az, size_x, size_y, N_x, N_y)
+                grid =sm.Grid(telescope, x_c, y_c, z_c, theta, alt,
+                              az, size_x, size_y, N_x, N_y)
             else:
                 raise ValueError('The input grid is not valid')
 
@@ -369,7 +298,7 @@ class _Event():
         kwargs['wvl_fin'] = kwargs.get('wvl_fin', signal.wvl_fin)
         kwargs['wvl_step'] = kwargs.get('wvl_step', signal.wvl_step)
 
-        grid_event = sm.Event(grid, self.shower, atm_trans, tel_eff, **kwargs)
+        grid_event = GridEvent(grid, self.shower, atm_trans, tel_eff, **kwargs)
         return grid_event.show_distribution()
 
     def make_images(self, lat_profile=True, NSB=40.):
@@ -384,11 +313,12 @@ class _Event():
             Use a NKG lateral profile to spread the signal. If False,
             a linear shower is assumed.
         NSB : float
-            Night sky background in MHz/m$^2$/deg$^2$.
+            Night sky background in MHz/m^2/deg^2.
 
         Returns
         -------
-        images : List of Image objects.
+        images : list
+            List of Image objects.
 
         See also
         --------
@@ -425,21 +355,102 @@ class _Event():
         #plt.show()
 
 
-class _GridEvent(_Event):
-    event_type = 'GridEvent'
+class GridEvent(Event):
+    """
+    Daughter class of Event used to calculate ground distributions.
+
+    A Grid object must be input to create a GridEvent. The event_type is set to
+    'GridEvent' and the attribute observatory is replaced by grid. The method
+    show_distribution does not accept arguments.
+    """
+
+    def __init__(self, grid, shower, atm_trans=True,
+                 tel_eff=True, **kwargs):
+        self.event_type = 'GridEvent'
+        _event(self, grid, shower, atm_trans, tel_eff, **kwargs)
 
     def show_distribution(self):  # Overwrite the method of the parent class
         """
-        Show the distribution of photons (or photoelectrons) per m$^2$ in an
+        Show the distribution of photons (or photoelectrons) per m^2 in an
         either 1D or 2D plot, depending on the grid dimensions.
         """
         return _show_distribution(self)
 
 
+# Constructor #################################################################
+def _event(event, observatory, shower, atm_trans, tel_eff, **kwargs):
+    """
+    Construct an Event object from a shower and an observatory.
+    
+    The Event objet contains the signal produced by the shower in each
+    telescope of the observatory.
+
+    Parameters
+    ----------
+    event : Event
+        Event to be generated.
+    observatory : Observatory
+        Observatory that observes the shower.
+    shower : Shower
+        Shower to be observed.
+    atm_trans : bool, default True
+        Include the atmospheric transmision to transport photons.
+    tel_eff : bool, default True
+        Include the telescope efficiency to calculate the signals.
+        If False, 100% efficiency is assumed for a given wavelength interval.
+    **kwargs : {wvl_ini, wvl_fin, wvl_step}
+        These parameters will be passed to the Signal constructor to modify
+        the wavelength interval when tel_eff==False. If None, the wavelength
+        interval defined in each telescope is used.
+    """
+    if not isinstance(shower, sm.Shower):
+        observatory, shower = (shower, observatory)
+        if not isinstance(shower, sm.Shower):
+            raise ValueError('The input shower is not valid')
+
+    if isinstance(event, GridEvent):
+        if isinstance(observatory, sm.Grid):
+            event.grid = observatory
+        else:
+            raise ValueError('The input grid is not valid')
+
+    if isinstance(observatory, (sm.Telescope, sm.Observatory)):
+        if isinstance(observatory, sm.Telescope):
+            telescope = observatory
+            event.observatory = sm.Observatory()
+            event.observatory.append(telescope)
+            event.observatory.N_tel = 1         
+        else:
+            event.observatory = observatory
+    else:
+        raise ValueError('The input observatory is not valid')
+
+    event.shower = shower
+    event.atmosphere = shower.atmosphere
+    event.track = shower.track
+    event.profile = shower.profile
+    event.cherenkov = shower.cherenkov
+    event.fluorescence = shower.fluorescence
+
+    event.atm_trans = atm_trans
+    event.tel_eff = tel_eff
+
+    event.projections = []
+    event.signals = []
+    for telescope in observatory:
+        projection = sm.Projection(telescope, event.track)
+        event.projections.append(projection)
+        signal = sm.Signal(
+            telescope, shower, projection, atm_trans, tel_eff, **kwargs)
+        event.signals.append(signal)
+    
+    event.images = None
+
+
 # Auxiliary functions #########################################################
 def _show_distribution(grid_event):
     """
-    Show the distribution of photons (or photoelectrons) per m$^2$ in an either
+    Show the distribution of photons (or photoelectrons) per m^2 in an either
     1D or 2D plot, depending on the grid dimensions.
     """
     grid = grid_event.grid
