@@ -9,15 +9,15 @@ from .track import _theta, _az, _x0, _y0
 from .profile import _E, _prf_model
 
 
-# Constructor #################################################################
-def Shower(E=_E, theta=_theta, alt=None, az=_az, x0=_x0, y0=_y0,
-           prf_model=_prf_model, X_max=None, N_ch_max=None, X0_GH=None,
-           lambda_GH=None, atmosphere=None, **kwargs):
+# Class #######################################################################
+class Shower:
     """
-    Make a discretization of shower.
+    Object containing a discretization of a shower.
 
-    It includes the shower profile and its fluorescence and Cherenkov light
-    production.
+    It includes the atmosphere, both the track and profile of the shower
+    as well as its fluorescence and Cherenkov light production.
+
+    Use sm.Shower() to construct the default Shower object.
 
     Parameters
     ----------
@@ -35,7 +35,7 @@ def Shower(E=_E, theta=_theta, alt=None, az=_az, x0=_x0, y0=_y0,
         East coordinate in km of shower impact point at ground.
     y0 : float
         West coordinate in km of shower impact point at ground.
-    prf_model : {'Greisen', 'Gaisser-Hillas'} or DataFrame
+    prf_model : 'Greisen', 'Gaisser-Hillas' or DataFrame
         If 'Greisen', the Greisen function for electromagnetic showers is used.
         If 'Gaisser-Hillas', the Gaisser-Hillas function for hadron-induced
         showers is used. If a DataFrame with an energy deposit profile is input,
@@ -53,82 +53,16 @@ def Shower(E=_E, theta=_theta, alt=None, az=_az, x0=_x0, y0=_y0,
     lambda_GH : float
         Lambda parameter in g/cm2 to be used when prf_model=='Gaisser-Hillas'.
         If None, a typical value for the input energy is used.
-    atmosphere : Atmosphere object.
+    atmosphere : Atmosphere
         If None, a new Atmosphere object is generated.
-    **kwargs {h0, h_top, N_steps, model}
+    **kwargs : {h0, h_top, N_steps, model}
         Options to construct the new Atmosphere object when atmosphere==None.
         If None, the default Atmosphere object is used.
 
-    Returns
-    -------
-    shower : Shower object.
-
-    See also
-    --------
-    _Shower : Shower class.
-    """
-    from .atmosphere import _Atmosphere
-    if isinstance(atmosphere, _Atmosphere):
-        pass
-    elif atmosphere is None:
-        atmosphere = sm.Atmosphere(**kwargs)
-    else:
-        raise ValueError('The input atmosphere is not valid.')
-
-    shower = _Shower()
-    shower.E = E
-    if alt is None:
-        alt = 90. - theta
-    else:
-        theta = 90. - alt
-    shower.theta = theta
-    shower.alt = alt
-    shower.az = az
-    shower.x0 = x0
-    shower.y0 = y0
-
-    # Atmosphere
-    shower.atmosphere = atmosphere
-
-    shower.h0 = atmosphere.h0
-    shower.h_top = atmosphere.h_top
-    shower.N_steps = atmosphere.N_steps
-    shower.model = atmosphere.model
-
-    # Shower track
-    shower.track = sm.Track(theta, None, az, x0, y0, atmosphere)
-
-    # Shower profile
-    profile = sm.Profile(E, theta, None, prf_model, X_max, X0_GH, lambda_GH,
-                         atmosphere)
-    shower.profile = profile
-
-    shower.prf_model = profile.prf_model
-    shower.X_max = profile.X_max
-    shower.X0_GH = profile.X0_GH
-    shower.lambda_GH = profile.lambda_GH
-
-    # Fluorescence emission
-    shower.fluorescence = shower.profile.Fluorescence()
-
-    # Cherenkov emission
-    shower.cherenkov = shower.profile.Cherenkov()
-
-    return shower
-
-
-# Class #######################################################################
-class _Shower:
-    """
-    Object containing a discretization of the atmosphere, both the track and
-    profile of a shower as well as its fluorescence and Cherenkov light
-    production.
-
-    Use Shower to construct a Shower object.
-
     Attributes
     ----------
-    atmosphere : Atmosphere object.
+    atmosphere : Atmosphere
+        Atmosphere object that is used.
     h0 : float
         Ground level in km above sea level.
     h_top : float
@@ -140,8 +74,10 @@ class _Shower:
     model : int
         CORSIKA atmospheric model. Presently either 1 or 17. More models to
         be implemented.
-    track : Track object.
-    profile : Profile object.
+    track : Track
+        Track object that is generated.
+    profile : Profile
+        Profile object that is generated.
     E : float
         Energy of the primary particle in MeV.
     theta : float
@@ -155,44 +91,29 @@ class _Shower:
         East coordinate in km of shower impact point at ground.
     y0 : float
         North coordinate in km of shower impact point at ground.
-    prf_model : {'Greisen', 'Gaisser-Hillas'} or DataFrame.
+    prf_model : 'Greisen', 'Gaisser-Hillas' or DataFrame.
     X_max : float
         Slant depth in g/cm^2 at shower maximum.
     X0_GH : float
         X0 parameter in g/cm2 for prf_model=='Gaisser-Hillas'.
     lambda_GH : float
         Lambda parameter in g/cm2 for prf_model=='Gaisser-Hillas'.
-    fluorescence : Fluorescence object.
-    cherenkov : Cherenkov object.
-
-    Methods
-    -------
-    copy : Copy a Shower object, but with optional changes.
-    Projection : Make a Projection object containing the coordinates of a
-        shower track relative to a telescope position.
-    Signal : Make a Signal object containing the signal produced by the shower
-        detected by a telescope.
-    Event : Make an Event object containing the characteristics of the shower,
-        an observatory and the signal produced by the shower in each telescope.
-    show_profile : Show the shower profile, both number of charged particles
-        and energy deposit, as a function of slant depth.
-    show_light_production : Show the production of both Cherenkov and
-        fluorescence photons in the 290 - 430 nm range as a function of slant
-        depth.
-    show_projection : Make a Projection object and show it.
-    show_signal : Make a Signal object and show it.
-    show_event : Make an Event object and show it.
-    show_geometry2D : Show a 2D plot of the shower track along with input
-        telescope positions.
-    show_geometry3D : Show a 3D plot of the shower track along with input
-        telescopes positions.
+    fluorescence : Fluorescence
+        Fluorescence object that is generated.
+    cherenkov : Cherenkov
+        Cherenkov object that is generated.
 
     See also
     --------
-    Atmosphere : Constructor of Atmosphere object.
-    Track : Constructor of Track object.
-    Profile : Constructor of Profile object.
+    Atmosphere : DataFrame containing the atmosphere discretization.
+    Track : DataFrame containing a shower track discretization.
+    Profile : DataFrame containing a shower profile discretization.
     """
+    def __init__(self, E=_E, theta=_theta, alt=None, az=_az, x0=_x0, y0=_y0,
+                 prf_model=_prf_model, X_max=None, N_ch_max=None, X0_GH=None,
+                 lambda_GH=None, atmosphere=None, **kwargs):
+        _shower(self, E, theta, alt, az, x0, y0, prf_model, X_max, N_ch_max,
+                X0_GH, lambda_GH, atmosphere, **kwargs)
 
     def copy(self, **kwargs):
         """
@@ -209,7 +130,7 @@ class _Shower:
 
         Returns
         -------
-        Shower object.
+        shower : Shower
 
         See also
         --------
@@ -225,12 +146,13 @@ class _Shower:
 
         Parameters
         ----------
-        telescope : Telescope object.
+        telescope : Telescope
+            Telescope object to be used.
 
         Returns
         -------
-        Projection object.
-        (ax1, ax2) : AxesSubplot objects.
+        projection : Projection
+        (ax1, ax2) : AxesSubplot
 
         See also
         --------
@@ -244,20 +166,21 @@ class _Shower:
 
         Parameters
         ----------
-        telescope : Telescope object.
+        telescope : Telescope
+            Telescope object to be used.
         atm_trans : bool, default True
             Include the atmospheric transmission.
         tel_eff : bool, default True
             Include the telescope efficiency. If False, 100% efficiency is
             assumed for a given wavelength interval.
-        **kwargs {wvl_ini, wvl_fin, wvl_step}
-            These parameters will modify the wavelenght interval when
+        **kwargs : {wvl_ini, wvl_fin, wvl_step}
+            These parameters will modify the wavelength interval when
             tel_eff==False. If None, the wavelength interval defined in the
             telescope is used.
 
-        Results
+        Returns
         -------
-        Signal object.
+        signal : Signal
         """
         return sm.Signal(telescope, self, atm_trans, tel_eff, **kwargs)
 
@@ -268,21 +191,22 @@ class _Shower:
 
         Parameters
         ----------
-        observatory : Observatory object (may be a Grid object).
+        observatory : Observatory 
+            Observatory object (may be a Grid object).
         atm_trans : bool, default True
             Include the atmospheric transmision to calculate the signals.
-        tel_eff : book, default True
+        tel_eff : bool, default True
             Include the telescope efficiency to calculate the signals.
             If False, 100% efficiency is assumed for a given
             wavelength interval.
-        **kwargs {wvl_ini, wvl_fin, wvl_step}
+        **kwargs : {wvl_ini, wvl_fin, wvl_step}
             These parameters will modify the wavelenght interval when
             tel_eff==False. If None, the wavelength interval defined in the
             telescope is used.
 
-        Results
+        Returns
         -------
-        Event object.
+        event : Event
         """
         return sm.Event(observatory, self, atm_trans, tel_eff, **kwargs)
 
@@ -293,11 +217,12 @@ class _Shower:
 
         Parameters
         ----------
-        telescope : Telescope object.
-        shower_size : book, default True
+        telescope : Telescope
+            Telescope object to be used.
+        shower_size : bool, default True
             Make the radii of the shower track points proportional to the
             shower size.
-        axes : book, default True
+        axes : bool, default True
             Show the axes of both frames of reference.
         max_theta : float, default 30 degrees
             Maximum offset angle in degrees relative to the telescope
@@ -309,8 +234,8 @@ class _Shower:
 
         Returns
         -------
-        Projection object.
-        (ax1, ax2) : PolarAxesSubpot objects.
+        projection : Projection
+        (ax1, ax2) : PolarAxesSubpot
 
         See also
         --------
@@ -331,7 +256,7 @@ class _Shower:
 
         Returns
         -------
-        (ax1, ax2) : AxesSubplot objects.
+        (ax1, ax2) : AxesSubplot
         """
         return self.profile.show()
 
@@ -342,7 +267,7 @@ class _Shower:
 
         Returns
         -------
-        (ax1, ax2) : AxesSubplot objects.
+        (ax1, ax2) : AxesSubplot
         """
         # Cherenkov
         fig, (ax1, ax2) = plt.subplots(nrows=1, ncols=2, figsize=(10, 5))
@@ -365,21 +290,22 @@ class _Shower:
 
         Parameters
         ----------
-        telescope : Telescope object.
+        telescope : Telescope
+            Telescope object to be used.
         atm_trans : bool, default True
             Include the atmospheric transmision.
         tel_eff : bool, default True
             Include the telescope efficiency. If False, 100% efficiency is
             assumed for a given wavelength interval.
-        **kwargs {wvl_ini, wvl_fin, wvl_step}
+        **kwargs : {wvl_ini, wvl_fin, wvl_step}
             These parameters will modify the wavelenght interval when
             tel_eff==False. If None, the wavelength interval defined in the
             telescope is used.
 
-        Results
+        Returns
         -------
-        Signal object.
-        (ax1, ax2) : AxesSubplot objects.
+        signal : Signal
+        (ax1, ax2) : AxesSubplot
         """
         signal = sm.Signal(telescope, self, atm_trans, tel_eff, **kwargs)
         ax1, ax2 = signal.show()
@@ -414,7 +340,7 @@ class _Shower:
 
         Returns
         -------
-        AxesSubplot object.
+        ax : AxesSubplot
         """
         if X_mark == 'X_max':
             X_mark = self.X_max
@@ -454,7 +380,7 @@ class _Shower:
 
         Returns
         -------
-        Axes3DSubplot object.
+        ax : Axes3DSubplot
         """
         if X_mark == 'X_max':
             X_mark = self.X_max
@@ -463,8 +389,7 @@ class _Shower:
                              y_max, X_mark, shower_size, False, False, xy_proj,
                              pointing)
 
-    def show_distribution(self, grid=None, telescope=None,
-                          tel_type='GridElement', x_c=0., y_c=0., z_c=0.,
+    def show_distribution(self, grid=None, telescope=None, x_c=0., y_c=0., z_c=0.,
                           theta=None, alt=None, az=None, size_x=2., size_y=2.,
                           N_x=10, N_y=10, atm_trans=True, tel_eff=False,
                           **kwargs):
@@ -475,18 +400,13 @@ class _Shower:
 
         Parameters
         ----------
-        grid : Grid object.
+        grid : Grid
             If None, a new Grid object is generated from the specificed
             dimensions and telescope characteristics.
             If given, {telescope, tel_type, ..., N_x, N_y} are not used.
-        telescope : Telescope object (when grid==None)
-            If None, the Grid object is constructed
-            based on a Telescope object of type tel_type.
-        tel_type : str
-            Subclass of Telescope to be used when grid==None and
-            telescope==None. Default to GridElement with 100% detection
-            efficiency, FoV of 180 degrees around zenith and area of one grid
-            cell. If tel_type==None, the parent class Telescope is used.
+        telescope : Telescope
+            When grid==None. If telescope==None, the Grid object is constructed
+            based on the default GridElement object.
         x_c : float
             x coordinate in km of the center of the grid.
         y_c : float
@@ -514,27 +434,27 @@ class _Shower:
         tel_eff : bool, default True
             Include the telescope efficiency to calculate the signal. If False,
             100% efficiency is assumed for a given wavelenght interval.
-        **kwargs {wvl_ini, wvl_fin, wvl_step}
+        **kwargs : {wvl_ini, wvl_fin, wvl_step}
             These parameters will modify the wavelenght interval when
             tel_eff==False. If None, the wavelength interval defined in the
             telescope is used.
 
         Returns
         -------
-        grid_event : GridEvent object.
-        ax : AxesSubplot object (if 1D grid).
-        (ax1, ax2, cbar) : AxesSubplot objects and Colorbar object
-            (if 2D grid).
+        grid_event : GridEvent
+        ax : AxesSubplot
+            If 1D grid.
+        (ax1, ax2, cbar) : AxesSubplot and Colorbar
+            If 2D grid.
         """
-        from .observatory import _Grid
-        if not isinstance(grid, _Grid):
+        if not isinstance(grid, sm.Grid):
             if grid is None:
-                grid = sm.Grid(telescope, tel_type, x_c, y_c, z_c, theta, alt,
+                grid = sm.Grid(telescope, x_c, y_c, z_c, theta, alt,
                                az, size_x, size_y, N_x, N_y)
             else:
                 raise ValueError('The input grid is not valid')
 
-        grid_event = sm.Event(grid, self, atm_trans, tel_eff, **kwargs)
+        grid_event = sm.GridEvent(grid, self, atm_trans, tel_eff, **kwargs)
         return grid_event.show_distribution()
 
 
@@ -565,8 +485,7 @@ def _copy(shower, atmosphere=None, **kwargs):
     N_steps = kwargs.get('N_steps', shower.N_steps)
     model = kwargs.get('model', shower.model)
 
-    from .atmosphere import _Atmosphere
-    if isinstance(atmosphere, _Atmosphere):
+    if isinstance(atmosphere, sm.Atmosphere):
         # If the key argument atmosphere is passed with a valid atmosphere,
         # the function generates a new shower from scratch using that
         # atmosphere (h0, h_top, etc. not used)
@@ -585,7 +504,7 @@ def _copy(shower, atmosphere=None, **kwargs):
             # If the atmospheric parameters are the same as the original
             # atmosphere a new Shower object is generated with an alias of the
             # original atmosphere
-            shower_c = _Shower()
+            shower_c = Shower()
             shower_c.atmosphere = shower.atmosphere  # New alias
 
             # Attributes are overwritten
@@ -632,3 +551,101 @@ def _copy(shower, atmosphere=None, **kwargs):
         shower_c.cherenkov = shower_c.profile.Cherenkov()
 
     return shower_c
+
+
+# Constructor #################################################################
+def _shower(shower, E, theta, alt, az, x0, y0, prf_model, X_max, N_ch_max,
+            X0_GH, lambda_GH, atmosphere, **kwargs):
+    """
+    Constructor of Shower object.
+
+    It includes the shower profile and its fluorescence and Cherenkov light
+    production.
+
+    Parameters
+    ----------
+    shower : Shower
+        Shower object.
+    E : float
+        Energy of the primary particle in MeV.
+    theta : float
+        Zenith angle in degrees of the apparent position of the source.
+    alt : float
+        Altitude in degrees of the apparent position of the source. If None,
+        theta is used. If given, theta is overwritten.
+    az : float
+        Azimuth angle (from north, clockwise) in degrees of the apparent
+        position of the source.
+    x0 : float
+        East coordinate in km of shower impact point at ground.
+    y0 : float
+        West coordinate in km of shower impact point at ground.
+    prf_model : {'Greisen', 'Gaisser-Hillas'} or DataFrame
+        If 'Greisen', the Greisen function for electromagnetic showers is used.
+        If 'Gaisser-Hillas', the Gaisser-Hillas function for hadron-induced
+        showers is used. If a DataFrame with an energy deposit profile is input,
+        it must have two columns with the slant depth in g/cm2 and dE/dX in
+        MeV.cm2/g. 
+    X_max : float
+        Slant depth in g/cm^2 at shower maximum. If None and prf_model is
+        'Greisen' or 'Gaisser-Hillas', a typical value of X_max for gamma or
+        proton showers is used. If None and a numerical energy deposit profile
+        is input, lambda_r = 36.7 g/cm^2 is the radiation length E_c = 81 MeV
+        is the critical energy.
+    X0_GH : float
+        X0 parameter in g/cm2 to be used when prf_model=='Gaisser-Hillas'.
+        If None, a typical value for the input energy is used.
+    lambda_GH : float
+        Lambda parameter in g/cm2 to be used when prf_model=='Gaisser-Hillas'.
+        If None, a typical value for the input energy is used.
+    atmosphere : Atmosphere
+        If None, a new Atmosphere object is generated.
+    **kwargs : {h0, h_top, N_steps, model}
+        Options to construct the new Atmosphere object when atmosphere==None.
+        If None, the default Atmosphere object is used.
+    """
+    if isinstance(atmosphere, sm.Atmosphere):
+        pass
+    elif atmosphere is None:
+        atmosphere = sm.Atmosphere(**kwargs)
+    else:
+        raise ValueError('The input atmosphere is not valid.')
+
+    # shower = Shower()
+    shower.E = E
+    if alt is None:
+        alt = 90. - theta
+    else:
+        theta = 90. - alt
+    shower.theta = theta
+    shower.alt = alt
+    shower.az = az
+    shower.x0 = x0
+    shower.y0 = y0
+
+    # Atmosphere
+    shower.atmosphere = atmosphere
+
+    shower.h0 = atmosphere.h0
+    shower.h_top = atmosphere.h_top
+    shower.N_steps = atmosphere.N_steps
+    shower.model = atmosphere.model
+
+    # Shower track
+    shower.track = sm.Track(theta, None, az, x0, y0, atmosphere)
+
+    # Shower profile
+    profile = sm.Profile(E, theta, None, prf_model, X_max, X0_GH, lambda_GH,
+                         atmosphere)
+    shower.profile = profile
+
+    shower.prf_model = profile.prf_model
+    shower.X_max = profile.X_max
+    shower.X0_GH = profile.X0_GH
+    shower.lambda_GH = profile.lambda_GH
+
+    # Fluorescence emission
+    shower.fluorescence = shower.profile.Fluorescence()
+
+    # Cherenkov emission
+    shower.cherenkov = shower.profile.Cherenkov()
\ No newline at end of file
