@@ -1,10 +1,10 @@
 def test_telescope():
-    from showermodel import Telescope
+    from showermodel import IACT
 
     # Default telescope type: IACT
     # Default angular aperture in degrees: 8.0
     # Default detection area in m2: 113.097
-    telescope = Telescope(tel_type='IACT')
+    telescope = IACT()
     assert telescope.tel_type == 'IACT'
     assert telescope.apert == 8.0
     assert telescope.area == 113.097
